@@ -1,8 +1,7 @@
 #!/usr/bin/perl -w
 use strict;
-use Win32::Clipboard;
-use Win32::Event;
-use Win32::Console::ANSI qw( Cls Cursor Title XYMax SetConsoleSize);
+use Win32::Pipe;
+use Win32::Console::ANSI qw( Cls Cursor Title XYMax SetConsoleSize );
 use Digest::MD5 qw(md5_hex);
 
 close STDOUT;                 # needed for Win9x
@@ -11,9 +10,7 @@ binmode STDOUT;
 select STDOUT;
 $|++;
 
-my $clip  = Win32::Clipboard();
-my $ready = Win32::Event->open('ReadyToReadClipboad');
-my $send  = Win32::Event->open('MessageAvailable');
+my $npipe = new Win32::Pipe("\\\\.\\pipe\\ANSINamedPipe", 1) or die $^E;
 my $n;
 
 my $s;
@@ -49,17 +46,13 @@ sub comp {            # compare screendump MD5 digests
     }
   }
   else {
-    $ready->wait();
-    $clip->Set($digest eq $dig[$n-1] ? "ok $n\n":"not ok $n\n");
-    $ready->reset();
-    $send->set();  
+    $npipe->Read();
+    $npipe->Write($digest eq $dig[$n-1] ? "ok $n\n":"not ok $n\n");
   }
 }
 
-$ready->wait();
-$clip->Set("1..35\n");        # <== test plan
-$ready->reset();
-$send->set();
+$npipe->Read();
+$npipe->Write("1..35\n");        # <== test plan
 
 # ****************************** BEGIN TESTS
 
@@ -168,11 +161,8 @@ if ($save) {
   close DIG;
 }
 
-$ready->wait();
-$clip->Set("_OVER");
-$ready->reset();
-$send->set();
-
-
-__END__
+$npipe->Read();
+$npipe->Write("_OVER");
+# $npipe->Close();
 
+__END__
\ No newline at end of file
